package net.sf.doolin.gui.action;

import javax.swing.KeyStroke;

import net.sf.doolin.gui.expression.GUIExpression;
import net.sf.doolin.gui.util.GUIStrings;

/**
 * Abstract implementation for an action is based on a text key.
 * 
 * @author Damien Coraboeuf
 * 
 */
public abstract class AbstractTextAction extends AbstractGUIAction {

	private final String id;
	private final String text;
	private final boolean textKey;

	/**
	 * Constructor for the action
	 * 
	 * @param id
	 *            Action id
	 * @param text
	 *            Key for the text
	 */
	public AbstractTextAction(String id, String text, boolean textKey) {
		this.id = id;
		this.text = text;
		this.textKey = textKey;
	}

	@Override
	public GUIExpression getIconIDExpression(ActionContext actionContext) {
		return null;
	}

	@Override
	public String getId() {
		return this.id;
	}

	/**
	 * Gets the shortcut for this action
	 * 
	 * @return Shortcut definition
	 * @see KeyStroke#getKeyStroke(String)
	 */
	protected abstract String getShortcut();

	@Override
	public GUIExpression getShortcutExpression(ActionContext actionContext) {
		return new GUIExpression(actionContext.getSubscriberValidator(),
				actionContext.getData(), getShortcut());
	}

	/**
	 * Gets the plain title for the action
	 * 
	 * @return Displayable text
	 */
	protected String getText() {
		if (this.textKey) {
			return GUIStrings.get(this.text);
		} else {
			return this.text;
		}
	}

	@Override
	public GUIExpression getTextExpression(ActionContext actionContext) {
		return new GUIExpression(actionContext.getSubscriberValidator(),
				actionContext.getData(), getText());
	}

	@Override
	public GUIExpression getTipExpression(ActionContext actionContext) {
		return new GUIExpression(actionContext.getSubscriberValidator(),
				actionContext.getData(), getText());
	}

}
