package net.sf.doolin.gui.action.path.item;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Stack;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;

/**
 * Basic implementation for an {@link ActionPath}. Its provides support for the
 * stack of paths.
 * 
 * @author Damien Coraboeuf
 * 
 */
public abstract class AbstractActionPath implements ActionPath {

	private final List<String> paths;

	/**
	 * Constructor with an empty stack.
	 */
	public AbstractActionPath() {
		this.paths = Collections.emptyList();
	}

	/**
	 * Constructor with a predefined stack.
	 * 
	 * @param paths
	 *            List of elements in the stack. It will be reverted to create
	 *            the stack.
	 */
	public AbstractActionPath(List<String> paths) {
		this.paths = paths;
	}

	/**
	 * Builds a path identifier from the path stack.
	 * 
	 * @return Identifier
	 */
	protected String getPathID() {
		return StringUtils.join(this.paths, ";");
	}

	@Override
	public Stack<String> getPathStack() {
		List<String> reversePaths = new ArrayList<String>(this.paths);
		Collections.reverse(reversePaths);
		Stack<String> stack = new Stack<String>();
		stack.addAll(reversePaths);
		return stack;
	}

	/**
	 * Returns <code>null</code>.
	 */
	@Override
	public String getSource() {
		return null;
	}

	/**
	 * Returns <code>null</code>.
	 */
	@Override
	public String getTarget() {
		return null;
	}

	@Override
	public String toString() {
		return ObjectUtils.toString(this.paths);
	}
}
