package net.sf.doolin.gui.action.path.item;

import java.util.List;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.action.swing.ActionFactory;
import net.sf.doolin.gui.action.swing.MenuBuilder;

/**
 * This action path defines a place holder that can be replaced by the content
 * of another action path.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class PlaceholderActionPath extends AbstractActionPath {

	private final String name;

	/**
	 * Constructor.
	 * 
	 * @param name
	 *            Placeholder name
	 * @param paths
	 *            List of paths
	 */
	public PlaceholderActionPath(String name, List<String> paths) {
		super(paths);
		this.name = name;
	}

	/**
	 * Returns the placeholder name
	 * 
	 * @return Placeholder name
	 */
	public String getName() {
		return this.name;
	}

	/**
	 * Returns the path identifier followed by the placeholder name
	 */
	@Override
	public String getTarget() {
		return getPathID() + ";@" + this.name;
	}

	/**
	 * Does nothing.
	 */
	@Override
	public void install(MenuBuilder menuBuilder, ActionFactory actionFactory,
			ActionContext actionContext) {
	}

	@Override
	public String toString() {
		return super.toString() + ">@" + this.name;
	}

}
