package net.sf.doolin.gui.action.path.item;

import java.util.List;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.action.swing.ActionFactory;
import net.sf.doolin.gui.action.swing.MenuBuilder;

/**
 * This action path delegates the installation to another action path.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class SubActionPath extends AbstractActionPath {

	private final ActionPath actionPath;

	/**
	 * Consttructor.
	 * 
	 * @param actionPath
	 *            Action path to delegate to
	 * @param pathList
	 *            Stack of paths
	 */
	public SubActionPath(ActionPath actionPath, List<String> pathList) {
		super(pathList);
		this.actionPath = actionPath;
	}

	/**
	 * Gets the action path the installation is delegated to
	 * 
	 * @return Action path
	 */
	public ActionPath getActionPath() {
		return this.actionPath;
	}

	/**
	 * @see ActionFactory#installAction(MenuBuilder, ActionPath, ActionContext)
	 */
	@Override
	public void install(MenuBuilder menuBuilder, ActionFactory actionFactory,
			ActionContext actionContext) {
		actionFactory
				.installAction(menuBuilder, this.actionPath, actionContext);
	}

}
