package net.sf.doolin.gui.action.swing;

import javax.swing.Action;
import javax.swing.JMenuBar;
import javax.swing.JPopupMenu;
import javax.swing.JToolBar;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.action.GUIAction;
import net.sf.doolin.gui.action.path.ActionBarContext;
import net.sf.doolin.gui.action.path.ActionContextPathList;
import net.sf.doolin.gui.action.path.item.ActionPath;
import net.sf.doolin.gui.service.IconSize;
import net.sf.doolin.gui.swing.JButtonBar;

/**
 * Defines the factory for components based on actions.
 * 
 * @author Damien Coraboeuf
 * 
 */
public interface ActionFactory {

	/**
	 * Creates a Swing {@link Action} from a {@link GUIAction}.
	 * 
	 * @param actionContext
	 *            Action context
	 * @param action
	 *            Associated {@link GUIAction}
	 * @param iconSize
	 *            Desired icon size
	 * @return Swing {@link Action}
	 */
	Action createAction(ActionContext actionContext, GUIAction action,
			IconSize iconSize);

	/**
	 * Creates a menu bar
	 * 
	 * @param menuBarContext
	 *            Menu bar description
	 * @return Menu bar
	 */
	JMenuBar createMenuBar(ActionContextPathList menuBarContext);

	/**
	 * Creates a button bar from a list of actions
	 * 
	 * @param actionBarContext
	 *            The action bar context
	 * @return Button bar
	 */
	JButtonBar createButtonBar(ActionBarContext actionBarContext);

	/**
	 * Creates a pop-up menu from an action group.
	 * 
	 * @param actionBarContext
	 *            The action bar context
	 * @return Pop-up menu
	 */
	JPopupMenu createPopupMenu(ActionBarContext actionBarContext);

	/**
	 * Creates a tool bar from an action group.
	 * 
	 * @param actionBarContext
	 *            The action bar context
	 * @return Tool bar
	 */
	JToolBar createToolBar(ActionBarContext actionBarContext);

	/**
	 * Installs an action path
	 * 
	 * @param menuBuilder
	 *            Menu builder
	 * @param actionPath
	 *            Action path to install
	 * @param actionContext
	 *            Action context
	 */
	void installAction(MenuBuilder menuBuilder, ActionPath actionPath,
			ActionContext actionContext);

}
