package net.sf.doolin.gui.action.task;

import net.sf.doolin.gui.action.ActionContext;

/**
 * Defines a task that can run in a GUI application. It is not run directly but
 * launched and monitored by a {@link GUITaskExecutor}.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <B>
 *            Type of bean sent to the task
 * @param <R>
 *            Type of bean returned by the task
 */
public interface GUITask<B, R> {

	/**
	 * Performs the main task, outside of the EDT.
	 * 
	 * @param actionContext
	 *            Initial action context
	 * @param bean
	 *            Bean sent to the task
	 * @return Bean returned by the task
	 * @throws Exception
	 *             In case of failure
	 */
	R doInBackground(ActionContext actionContext, B bean) throws Exception;

	/**
	 * This method is called by the task executor whenever that task has
	 * returned an error
	 * 
	 * @param actionContext
	 *            Initial action context
	 * @param bean
	 *            Bean sent to the task
	 * @param th
	 *            Error thrown by the task
	 */
	void doOnException(ActionContext actionContext, B bean, Throwable th);

	/**
	 * This method is called on the EDT when the task has completed its work.
	 * 
	 * @param actionContext
	 *            Initial action context
	 * @param bean
	 *            Bean sent to the task
	 * @param result
	 *            Bean returned by the task
	 */
	void doOnResult(ActionContext actionContext, B bean, R result);

}
