package net.sf.doolin.gui.app.support;

import javax.swing.SwingUtilities;

import net.sf.doolin.gui.app.GUIApplication;
import net.sf.doolin.gui.app.GUIStartup;
import net.sf.doolin.gui.window.GUIWindow;
import net.sf.doolin.gui.window.descriptor.GUIWindowDescriptor;
import net.sf.doolin.util.factory.DataFactory;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Required;

/**
 * Starts the application by creating a window and displaying it.
 * 
 * @author Damien Coraboeuf
 * @param <B>
 *            Type of the bean of the window
 */
public class GUIWindowStartup<B> implements GUIStartup {

	private final static Logger log = LoggerFactory.getLogger(GUIWindowStartup.class);

	private DataFactory<B> dataFactory;

	private GUIWindowDescriptor<B> windowDescriptor;

	/**
	 * Gets the data factory.
	 * 
	 * @return the data factory
	 */
	public DataFactory<B> getDataFactory() {
		return this.dataFactory;
	}

	/**
	 * Gets the window descriptor.
	 * 
	 * @return the window descriptor
	 */
	public GUIWindowDescriptor<B> getWindowDescriptor() {
		return this.windowDescriptor;
	}

	/**
	 * Data factory that creates the bean for the window
	 * 
	 * @param dataFactory
	 *            the new data factory
	 */
	@Required
	public void setDataFactory(DataFactory<B> dataFactory) {
		this.dataFactory = dataFactory;
	}

	/**
	 * Descriptor for the window to create
	 * 
	 * @param windowDescriptor
	 *            the new window descriptor
	 */
	@Required
	public void setWindowDescriptor(GUIWindowDescriptor<B> windowDescriptor) {
		this.windowDescriptor = windowDescriptor;
	}

	/**
	 * {@inheritDoc}.
	 * 
	 * @param application
	 *            the application
	 */
	@Override
	public void start(GUIApplication application, String[] arguments) {
		log.debug("Startup sequence");
		// Root bean
		B data = null;
		if (this.dataFactory != null) {
			data = this.dataFactory.create(null);
		}
		log.debug("Window data is " + data);
		// Creates the window
		final GUIWindow<B> window = this.windowDescriptor.createWindow(
				application, data);
		log.debug("Window is " + window);
		// Displays the window on the EDT
		SwingUtilities.invokeLater(new Runnable() {

			@Override
			public void run() {
				log.debug("Displaying the window");
				window.display();
			}

		});
		log.debug("End of startup sequence");
	}

}
