package net.sf.doolin.gui.bus;

import java.text.SimpleDateFormat;

import net.sf.doolin.gui.field.AbstractFieldDescriptor;
import net.sf.doolin.gui.field.Field;
import net.sf.doolin.gui.field.support.SimpleField;
import net.sf.doolin.gui.view.GUIView;

import org.jfree.chart.ChartFactory;
import org.jfree.chart.ChartPanel;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.DateAxis;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.chart.plot.XYPlot;
import org.jfree.data.time.Millisecond;
import org.jfree.data.time.TimeSeries;
import org.jfree.data.time.TimeSeriesCollection;

import ca.odell.glazedlists.EventList;
import ca.odell.glazedlists.event.ListEvent;
import ca.odell.glazedlists.event.ListEventListener;
import ca.odell.glazedlists.util.concurrent.Lock;

public class BusMonitoringChartField extends
		AbstractFieldDescriptor<BusMonitoringModel> {

	@Override
	public Field<BusMonitoringModel> createField(
			GUIView<BusMonitoringModel> view) {

		// Charts
		ChartPanel chartPanel = new ChartPanel(null);
		final SimpleField<BusMonitoringModel> field = new SimpleField<BusMonitoringModel>(
				view, this, chartPanel);

		// Update of the chart from the model
		final BusMonitoringModel model = view.getViewData();
		final Runnable updateTask = new Runnable() {

			@Override
			public void run() {
				update(field, model);
			}
		};

		// Model -> Chart
		model.getStatList().addListEventListener(
				new ListEventListener<BusMonitoringStat>() {

					@Override
					public void listChanged(ListEvent<BusMonitoringStat> e) {
						updateTask.run();
					}
				});

		// Initialisation
		updateTask.run();

		// OK
		return field;
	}

	protected void update(SimpleField<BusMonitoringModel> field,
			BusMonitoringModel model) {
		// Chart panel
		ChartPanel chartPanel = (ChartPanel) field.getFieldComponent();

		// List of values
		EventList<BusMonitoringStat> statList = model.getStatList();
		Lock lock = statList.getReadWriteLock().readLock();
		lock.lock();
		try {

			// Count serie
			TimeSeries countSeries = new TimeSeries("Count", Millisecond.class);
			for (BusMonitoringStat stat : statList) {
				countSeries.add(new Millisecond(stat.getDateTime().toDate()),
						stat.getCount());
			}

			// Max serie
			TimeSeries maxSeries = new TimeSeries("Maximum", Millisecond.class);
			for (BusMonitoringStat stat : statList) {
				maxSeries.add(new Millisecond(stat.getDateTime().toDate()),
						stat.getMaximum());
			}

			// Dataset
			TimeSeriesCollection collection = new TimeSeriesCollection();
			collection.addSeries(countSeries);
			collection.addSeries(maxSeries);

			// Chart
			JFreeChart chart = ChartFactory.createXYLineChart(
					"Subscription count", "Timestamp", null, collection,
					PlotOrientation.VERTICAL, true, false, false);
			chartPanel.setChart(chart);
			chartPanel.setVisible(true);

			// Plot
			XYPlot plot = chart.getXYPlot();

			// Domain axis
			DateAxis axis = new DateAxis();
			axis.setDateFormatOverride(new SimpleDateFormat("HH:mm:ss.SSS"));
			plot.setDomainAxis(axis);
		} finally {
			lock.unlock();
		}
	}
}
