package net.sf.doolin.gui.bus;

import net.sf.doolin.bus.BusLog;
import net.sf.doolin.bus.Priority;
import net.sf.doolin.bus.Subscriber;
import net.sf.doolin.bus.bean.Bean;
import ca.odell.glazedlists.BasicEventList;
import ca.odell.glazedlists.EventList;
import ca.odell.glazedlists.util.concurrent.Lock;

public class BusMonitoringLog extends Bean implements BusLog {

	public static final String LOGGING_LIMIT = "loggingLimit";

	private final BusLog defaultLog;
	private final EventList<BusMonitoringLogEntry> entries = new BasicEventList<BusMonitoringLogEntry>();

	private int loggingLimit = 100;

	public BusMonitoringLog(BusLog defaultLog) {
		this.defaultLog = defaultLog;
	}

	public void clear() {
		Lock lock = this.entries.getReadWriteLock().writeLock();
		lock.lock();
		try {
			this.entries.clear();
		} finally {
			lock.unlock();
		}
	}

	public EventList<BusMonitoringLogEntry> getEntries() {
		return this.entries;
	}

	public int getLoggingLimit() {
		return this.loggingLimit;
	}

	public <M> void messageAccepted(M message, Subscriber<M> subscriber) {
		this.defaultLog.messageAccepted(message, subscriber);
		// Logs the message
		Lock lock = this.entries.getReadWriteLock().writeLock();
		lock.lock();
		try {
			this.entries.add(new BusMonitoringLogEntry(message, subscriber));
			if (this.entries.size() > this.loggingLimit) {
				while (this.entries.size() > this.loggingLimit) {
					this.entries.remove(0);
				}
			}
		} finally {
			lock.unlock();
		}
	}

	public void messageNoSubscription(Object message) {
		this.defaultLog.messageNoSubscription(message);
	}

	public void messageReceived(Object message) {
		this.defaultLog.messageReceived(message);
	}

	public <M> void messageWithError(M message, Subscriber<M> subscriber,
			Throwable th) {
		this.defaultLog.messageWithError(message, subscriber, th);
	}

	public void registrationFailed(Subscriber<?> subscriber, Priority priority) {
		this.defaultLog.registrationFailed(subscriber, priority);
	}

	public void registrationOk(Subscriber<?> subscriber, Priority priority) {
		this.defaultLog.registrationOk(subscriber, priority);
	}

	public void setLoggingLimit(int loggingLimit) {
		notify(LOGGING_LIMIT, this.loggingLimit,
				this.loggingLimit = loggingLimit);
		// Trim list
		Lock lock = this.entries.getReadWriteLock().writeLock();
		lock.lock();
		try {
			if (this.entries.size() > loggingLimit) {
				while (this.entries.size() > loggingLimit) {
					this.entries.remove(0);
				}
			}
		} finally {
			lock.unlock();
		}

	}

	public void unregistration(Subscriber<?> subscriber) {
		this.defaultLog.unregistration(subscriber);
	}

}
