package net.sf.doolin.gui.bus;

import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JCheckBox;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import net.sf.doolin.bus.support.PropertyChangeSupport;
import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.action.path.item.AbstractActionPath;
import net.sf.doolin.gui.action.swing.ActionFactory;
import net.sf.doolin.gui.action.swing.MenuBuilder;

public class BusMonitoringRefreshActionPath extends AbstractActionPath {

	@Override
	public void install(MenuBuilder menuBuilder, ActionFactory actionFactory,
			ActionContext actionContext) {

		// Model
		final BusMonitoringModel model = (BusMonitoringModel) actionContext
				.getData();

		// Master component to install
		JPanel masterPanel = new JPanel(new FlowLayout(FlowLayout.LEADING));

		// Interval
		final SpinnerNumberModel spinIntervalModel = new SpinnerNumberModel(
				model.getRefreshInterval(), 1, 3600, 1);
		final JSpinner spinInterval = new JSpinner(spinIntervalModel);
		masterPanel.add(spinInterval);

		// Autorefresh
		final JCheckBox chkAuto = new JCheckBox("Auto-refresh");
		masterPanel.add(chkAuto);

		// Model -> Components
		Runnable updateComponentsTask = new Runnable() {

			@Override
			public void run() {
				spinInterval.setValue(model.getRefreshInterval());
				chkAuto.setSelected(model.isAutoRefresh());
			}
		};
		PropertyChangeSupport.subscribe(actionContext.getSubscriberValidator(),
				model, "refreshInterval", updateComponentsTask);
		PropertyChangeSupport.subscribe(actionContext.getSubscriberValidator(),
				model, "autoRefresh", updateComponentsTask);

		// Components -> Model
		chkAuto.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				boolean value = chkAuto.isSelected();
				model.setAutoRefresh(value);
			}
		});
		spinIntervalModel.addChangeListener(new ChangeListener() {

			@Override
			public void stateChanged(ChangeEvent e) {
				int value = (Integer) spinIntervalModel.getValue();
				model.setRefreshInterval(value);
			}
		});

		// Initialisation
		updateComponentsTask.run();

		// Installs the component
		menuBuilder.add(masterPanel);
	}

}
