package net.sf.doolin.gui.display;

import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Required;

/**
 * Adapter based on a map.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <S>
 *            Type of the source
 */
public class MapStateAdapter<S> extends AbstractStateAdapter<S> {

	private static final Logger log = LoggerFactory.getLogger(MapStateAdapter.class);

	private DisplayState defaultState = DisplayState.DISABLED;
	private Map<S, DisplayState> map;

	/**
	 * Gets the default state.
	 * 
	 * @return the default state
	 */
	public DisplayState getDefaultState() {
		return this.defaultState;
	}

	/**
	 * Default state when not mapped
	 * 
	 * @param defaultState
	 *            the new default state
	 */
	public void setDefaultState(DisplayState defaultState) {
		this.defaultState = defaultState;
	}

	/**
	 * Gets the map.
	 * 
	 * @return the map
	 */
	public Map<S, DisplayState> getMap() {
		return this.map;
	}

	/**
	 * Map of subject values to the display state
	 * 
	 * @param map
	 *            the map
	 */
	@Required
	public void setMap(Map<S, DisplayState> map) {
		this.map = map;
	}

	@Override
	public DisplayState convertSubjectToTarget(S subjectValue) {
		DisplayState state = this.map.get(subjectValue);
		if (state == null) {
			state = this.defaultState;
		}
		log.debug(String.format("Map %s to %s", subjectValue, state));
		return state;
	}

}
