package net.sf.doolin.gui.display;

import net.sf.doolin.bus.support.PropertyChangeSupport;
import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.validation.ValidationSupport;

/**
 * Display state handler based on the validation status of a GUI model.
 * 
 * @author Damien Coraboeuf
 * 
 * @see ActionContext#getView()
 * @see net.sf.doolin.gui.view.GUIView#getViewData()
 * @see ActionContext#getValidationSupport()
 * @see ValidationSupport#getValidation()
 */
public class ValidationDisplayStateHandler extends AbstractDisplayStateHandler {

	private DisplayState notValidState = DisplayState.DISABLED;

	/**
	 * Gets the not valid state.
	 * 
	 * @return the not valid state
	 */
	public DisplayState getNotValidState() {
		return this.notValidState;
	}

	/**
	 * State when the validation is not valid
	 * 
	 * @param notValidState
	 *            the new not valid state
	 */
	public void setNotValidState(DisplayState notValidState) {
		this.notValidState = notValidState;
	}

	@Override
	public DisplayState getDisplayState(ActionContext actionContext) {
		ValidationSupport<?> validationSupport = actionContext
				.getValidationSupport();
		if (validationSupport.isValid()) {
			return DisplayState.ENABLED;
		} else {
			return this.notValidState;
		}
	}

	@Override
	public void subscribe(ActionContext actionContext, Runnable task) {
		ValidationSupport<?> validationSupport = actionContext
				.getValidationSupport();
		PropertyChangeSupport.subscribe(actionContext.getSubscriberValidator(),
				validationSupport, "validation", task);
	}

}
