package net.sf.doolin.gui.expression;

import net.sf.doolin.bus.expression.BusExpression;
import net.sf.doolin.bus.support.SubscriberValidator;

/**
 * A {@link GUIExpression} is basically a text string whose content can be
 * created from bundle keys or properties in a bean model.
 * 
 * <p>
 * Tokens that are used are:
 * <ul>
 * <li>\@{propertyPath} - this token is replaced by the value defined by the
 * property in the bean model.
 * <li>#{key} - this token is replaced by a string whose bundle key is
 * <code>key</code>. If the key has parameters, parameters can be indicated
 * using <code>#{key:param1,param2}</code> where parameters themselves are
 * {@link GUIExpression} instances.
 * <li>Any other text is considered as hard-coded text
 * <li>The \ character can be used to escape any special character
 * </ul>
 * 
 * <p>
 * Since a {@link GUIExpression} is linked to a bean model, its value may change
 * it the model changes. The {@link #isVariable()} method can be called to check
 * if such changes can happen (for example, expressions containing only leys and
 * text cannot change).
 * 
 * <p>
 * To listens to the changes, one can do:
 * 
 * <pre>
 * GUIExpression expression = ...
 * String initialValue = expression.getValue();
 * if (expression.isVariable()) {
 * 	expression.getValueModel().addValueChangeListener(new PropertyChangeListener () {
 * 		public void propertyChange(PropertyChangeEvent evt) {
 * 			String newExpressionValue = (String) evt.getNewValue();
 * 			...
 * 		} 
 * 	});
 * }
 * </pre>
 * 
 * @author Damien Coraboeuf
 */
public class GUIExpression extends BusExpression {

	/**
	 * Expression with a fixed text, using the default locale.
	 * 
	 * @param text
	 *            Fixed text
	 */
	public GUIExpression(String text) {
		super(text);
	}

	/**
	 * Expression with a pattern, using the default locale.
	 * 
	 * @param validator
	 *            Validator for bus registration
	 * @param context
	 *            Context for the evaluation
	 * @param pattern
	 *            Pattern to evaluate agains the context
	 */
	public GUIExpression(SubscriberValidator validator, Object context,
			String pattern) {
		super(validator, context, pattern);
	}
}
