package net.sf.doolin.gui.field;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.BorderFactory;
import javax.swing.JColorChooser;
import javax.swing.JPanel;

import net.sf.doolin.gui.field.support.SimpleField;
import net.sf.doolin.gui.view.GUIView;

/**
 * This field allows the user to select a color.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of bean for the view
 */
public class FieldColor<V> extends AbstractPropertyFieldDescriptor<V> {

	private static final long serialVersionUID = 1L;

	@Override
	public Field<V> createField(final GUIView<V> view) { // Panel for selection
		final JPanel panel = new JPanel();
		panel.setPreferredSize(new Dimension(16, 16));
		panel.setBorder(BorderFactory.createEtchedBorder());
		// Event handling
		panel.addMouseListener(new MouseAdapter() {

			@Override
			public void mouseClicked(MouseEvent e) {
				if (e.getButton() == MouseEvent.BUTTON1) {
					Color color = panel.getBackground();
					color = JColorChooser.showDialog(panel, null, color);
					if (color != null) {
						panel.setBackground(color);
						setProperty(view, color);
					}
				}
			}

		});
		// Model -> Panel
		subscribe(view, panel, "background");
		// OK
		return new SimpleField<V>(view, this, panel);
	}
}
