package net.sf.doolin.gui.field;

import javax.swing.JComponent;
import javax.swing.TransferHandler;

import net.sf.doolin.gui.action.swing.ActionFactory;
import net.sf.doolin.gui.display.DisplayState;
import net.sf.doolin.gui.display.DisplayStateHandler;
import net.sf.doolin.gui.style.Style;
import net.sf.doolin.gui.view.GUIView;

/**
 * Field definition.
 * 
 * @author Damien Coraboeuf
 * @param <V>
 *            Type of object for the view
 */
public interface FieldDescriptor<V> {

	/**
	 * Creates a field.
	 * 
	 * @param view
	 *            Owning view
	 * 
	 * @return Created field
	 */
	Field<V> createField(GUIView<V> view);

	/**
	 * Returns the action factory
	 * 
	 * @return Action factory
	 */
	ActionFactory getActionFactory();

	/**
	 * Layout constraint for the field.
	 * 
	 * @return Constraint
	 */
	String getConstraint();

	/**
	 * Gets the display state handler.
	 * 
	 * @return the display state handler
	 */
	DisplayStateHandler getDisplayStateHandler();

	/**
	 * Name for the field.
	 * 
	 * @return Name
	 */
	String getName();

	/**
	 * Returns the style to apply on the field component
	 * 
	 * @return Style to apply or <code>null</code> if none is to be applied.
	 */
	Style getStyle();

	/**
	 * Returns the transfer handler associated with this field.
	 * 
	 * @return Transfer handler or <code>null</code>
	 * @see JComponent#setTransferHandler(TransferHandler)
	 */
	TransferHandler getTransferHandler();

	/**
	 * Called when the field view is created. It can be called only once per
	 * field.
	 * 
	 * @param field
	 *            Field that is created
	 */
	void onInit(Field<V> field);

	/**
	 * Called when the field is shown for the user. It can be called several
	 * times.
	 * 
	 * @param field
	 *            Field that is shown
	 */
	void onShow(Field<V> field);

	/**
	 * Sets the display state of the field
	 * 
	 * @param field
	 *            Field
	 * @param component
	 *            Decorated field component
	 * @param displayState
	 */
	void setDisplayState(Field<V> field, JComponent component,
			DisplayState displayState);

}
