/**
 * 
 */
package net.sf.doolin.gui.field.list.multi;

import java.util.Comparator;

import net.sf.doolin.gui.action.support.ActionDelegate;
import net.sf.doolin.util.EditableValue;
import ca.odell.glazedlists.gui.AdvancedTableFormat;
import ca.odell.glazedlists.gui.WritableTableFormat;

/**
 * Table format for the list of selectable items.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <E>
 *            type of item
 */
public class MultiComboTableFormat<V, E> implements AdvancedTableFormat<SelectableItem<E>>, WritableTableFormat<SelectableItem<E>> {

	private final MultiComboField<V, E> field;

	/**
	 * Column index for the selection
	 */
	public static final int COL_SELECTED = 0;

	/**
	 * Column index for the item
	 */
	public static final int COL_ITEM = 1;

	@SuppressWarnings("unchecked")
	private static final Class[] CLASSES = { Boolean.class, Object.class };

	/**
	 * Constructor
	 * 
	 * @param field
	 *            Field definition
	 */
	public MultiComboTableFormat(MultiComboField<V, E> field) {
		this.field = field;
	}

	@Override
	public Class<?> getColumnClass(int column) {
		return CLASSES[column];
	}

	@Override
	public Comparator<?> getColumnComparator(int column) {
		return null;
	}

	@Override
	public int getColumnCount() {
		return 2;
	}

	@Override
	public String getColumnName(int column) {
		return "";
	}

	@Override
	public Object getColumnValue(SelectableItem<E> baseObject, int column) {
		if (column == COL_SELECTED) {
			return baseObject.isSelected();
		} else if (column == COL_ITEM) {
			return baseObject.getItem();
		} else {
			throw new IllegalArgumentException(String.format("Unknown column: %s", column));
		}
	}

	@Override
	public boolean isEditable(SelectableItem<E> baseObject, int column) {
		if (column == COL_SELECTED) {
			return true;
		} else if (column == COL_ITEM) {
			return this.field.getMultiComboDescriptor().isEditable();
		} else {
			throw new IllegalArgumentException(String.format("Unknown column: %s", column));
		}
	}

	@Override
	public SelectableItem<E> setColumnValue(SelectableItem<E> baseObject, Object editedValue, int column) {
		if (column == COL_SELECTED) {
			baseObject.setSelected((Boolean) editedValue);
			// Edit the selection list
			this.field.select(baseObject);
			// OK
			return baseObject;
		} else if (column == COL_ITEM) {
			ActionDelegate<EditableValue<E>> updateDelegate = this.field.getMultiComboDescriptor().getUpdateDelegate();
			if (updateDelegate != null) {
				EditableValue<E> editableValue = new EditableValue<E>(baseObject.getItem(), editedValue);
				updateDelegate.call(this.field.getActionContext(), editableValue);
				boolean ok = editableValue.isEdited();
				if (ok) {
					return baseObject;
				} else {
					return null;
				}
			} else {
				return null;
			}
		} else {
			throw new IllegalArgumentException(String.format("Unknown column: %s", column));
		}
	}
}