package net.sf.doolin.gui.field.table;

import javax.swing.ListSelectionModel;

/**
 * This enumeration defines the different selection modes for a
 * {@link FieldTable}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public enum TableSelectionMode {

	/**
	 * Same semantics than {@link ListSelectionModel#SINGLE_INTERVAL_SELECTION}
	 */
	MULTIPLE_CONTINUOUS(true, ListSelectionModel.SINGLE_INTERVAL_SELECTION),
	/**
	 * Same semantics than
	 * {@link ListSelectionModel#MULTIPLE_INTERVAL_SELECTION}
	 */
	MULTIPLE(true, ListSelectionModel.MULTIPLE_INTERVAL_SELECTION),
	/**
	 * Same semantics than {@link ListSelectionModel#SINGLE_SELECTION}
	 */
	SINGLE(false, ListSelectionModel.SINGLE_SELECTION);

	private final boolean multiple;
	private final int selectionMode;

	private TableSelectionMode(boolean multiple, int selectionMode) {
		this.multiple = multiple;
		this.selectionMode = selectionMode;
	}

	/**
	 * Checks if this selection mode means a multiple selection
	 * 
	 * @return <code>true</code> if several items may be selected
	 */
	public boolean isMultiple() {
		return this.multiple;
	}

	/**
	 * Gets the selection mode as for use in
	 * {@link ListSelectionModel#setSelectionMode(int)}.
	 * 
	 * @return Selection mode
	 */
	public int getSelectionMode() {
		return this.selectionMode;
	}

}
