package net.sf.doolin.gui.field.table.value;

import java.util.Comparator;

import net.sf.doolin.gui.field.table.ColumnValueFactory;
import net.sf.doolin.util.Utils;

import org.springframework.beans.factory.annotation.Required;

/**
 * Column value based on a property path.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class PropertyColumnValueFactory implements ColumnValueFactory {

	private String propertyPath;

	/**
	 * Gets the property path.
	 * 
	 * @return the property path
	 */
	public String getPropertyPath() {
		return this.propertyPath;
	}

	/**
	 * Sets the path to the property of the colum.
	 * 
	 * @param propertyPath
	 *            the new property path
	 */
	@Required
	public void setPropertyPath(String propertyPath) {
		this.propertyPath = propertyPath;
	}

	@Override
	public Object getValue(Object item) {
		return Utils.getProperty(item, this.propertyPath);
	}

	@Override
	public void setValue(Object item, Object value) {
		Utils.setProperty(item, this.propertyPath, value);
	}

	@Override
	public Comparator<?> getComparator() {
		return new Comparator<Object>() {

			@SuppressWarnings("unchecked")
			@Override
			public int compare(Object o1, Object o2) {
				if (o1 instanceof Comparable && o2 instanceof Comparable) {
					return ((Comparable) o1).compareTo(o2);
				} else {
					return String.valueOf(o1).compareTo(String.valueOf(o2));
				}
			}

		};
	}

}
