package net.sf.doolin.gui.field.tree.model;

import java.util.List;

import javax.swing.tree.DefaultTreeModel;

import net.sf.doolin.bus.support.SubscriberValidator;
import net.sf.doolin.gui.field.tree.Node;

import org.apache.commons.lang.StringUtils;

public class GUITreeModel extends DefaultTreeModel {

	private final Object rootObject;
	private final List<Node> nodes;

	public GUITreeModel(SubscriberValidator validator, Object rootObject,
			List<Node> nodes) {
		super(null);
		this.rootObject = rootObject;
		this.nodes = nodes;
		init(validator);
	}

	/**
	 * Looks for a node definition. The node definition to look for is the one
	 * whose property <code>id</code> is equal to the given id.
	 * 
	 * @param id
	 *            Searched id
	 * @return Node definition
	 */
	public Node getNode(String id) {
		for (Node node : this.nodes) {
			if (StringUtils.equals(id, node.getId())) {
				return node;
			}
		}
		throw new RuntimeException("Cannot find any node with id = " + id);
	}

	/**
	 * Looks for the root node definition. The root node definition is the node
	 * definition whose property <code>root</code> is set to <code>true</code>.
	 * 
	 * @return Root node definition
	 */
	protected Node getRootNode() {
		for (Node node : this.nodes) {
			if (node.isRoot()) {
				return node;
			}
		}
		throw new IllegalStateException("Cannot find any root node.");
	}

	/**
	 * Initializes the model
	 */
	protected void init(SubscriberValidator validator) {
		// Looks for the root definition
		Node rootNode = getRootNode();
		// Creates the root
		GUITreeNode rootTreeNode = new GUITreeNode(validator, this, rootNode,
				this.rootObject);
		// Set as root
		setRoot(rootTreeNode);
	}
}
