package net.sf.doolin.gui.field.tree.support;

import javax.swing.JComponent;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;

import net.sf.doolin.bus.support.SubscriberValidator;
import net.sf.doolin.gui.app.GUIApplication;
import net.sf.doolin.gui.field.support.AbstractFieldActionContext;
import net.sf.doolin.gui.view.GUIView;
import net.sf.doolin.gui.view.support.ViewSubscriberValidator;
import net.sf.doolin.gui.window.GUIWindow;

/**
 * {@link net.sf.doolin.gui.action.ActionContext} for a {@link GUITree}. It
 * defines a <code>context</code> property that can be listened to.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of object for the view
 */
public class TreeActionContext<V> extends AbstractFieldActionContext {

	private static final long serialVersionUID = 1L;

	private final GUITreeField<V> treeField;

	private final SubscriberValidator subscriberValidator;

	/**
	 * Constructor
	 * 
	 * @param treeField
	 *            Associated tree field
	 */
	public TreeActionContext(GUITreeField<V> treeField) {
		this.treeField = treeField;
		init();
		// Subscription
		GUIView<V> view = getView();
		this.subscriberValidator = new ViewSubscriberValidator<V>(view);
	}

	@Override
	public GUIApplication getApplication() {
		return getView().getApplication();
	}

	@Override
	public JComponent getComponent() {
		return this.treeField.getTree();
	}

	@Override
	public Object getData() {
		return getView().getViewData();
	}

	@Override
	public SubscriberValidator getSubscriberValidator() {
		return this.subscriberValidator;
	}

	@SuppressWarnings("unchecked")
	@Override
	public <T> GUIView<T> getView() {
		return (GUIView<T>) this.treeField.getView();
	}

	@SuppressWarnings("unchecked")
	@Override
	public <T> GUIWindow<T> getWindow() {
		return (GUIWindow<T>) getView().getParentWindow();
	}

	/**
	 * Initialisation.
	 */
	protected void init() {
		final GUITree<V> tree = this.treeField.getTree();
		tree.getSelectionModel().addTreeSelectionListener(
				new TreeSelectionListener() {

					@Override
					public void valueChanged(TreeSelectionEvent e) {
						// Gets the selected value
						Object value = tree.getSelection();
						setContext(value);
					}
				});
		// Initial value
		setContext(tree.getSelection());
	}

}
