package net.sf.doolin.gui.layout;

import java.awt.BorderLayout;

import javax.swing.BorderFactory;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;

import net.sf.doolin.gui.util.GUIStrings;

import org.apache.commons.lang.StringUtils;

import com.jgoodies.forms.builder.DefaultFormBuilder;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.forms.layout.RowSpec;

/**
 * Layouts component using a two-columns table.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class TableLayoutService implements LayoutService {

	private String columnSpecs = "default,2dlu,fill:default:grow";

	@Override
	public void add(JPanel panel, JComponent component, Object constraint) {
		FormLayout layout = (FormLayout) panel.getLayout();
		// Field row
		layout.appendRow(RowSpec.decode("default"));
		int row = layout.getRowCount();
		// Constraints
		CellConstraints cc = new CellConstraints();
		// Decoration
		component = decorate(component);
		// Field
		panel.add(component, cc.xy(3, row));
		// Label
		String key = (String) constraint;
		if (StringUtils.isNotBlank(key) && GUIStrings.isDefined(key)) {
			String text = GUIStrings.get(key);
			JLabel label = new JLabel(text);
			panel.add(label, cc.xy(1, row));
			label.setLabelFor(component);
		}
		// Separator
		layout.appendRow(RowSpec.decode("2dlu"));
	}

	/**
	 * Decorates a component before it is put in the layout.
	 * 
	 * @param component
	 *            Component to decorate
	 * @return Decorated component
	 */
	protected JComponent decorate(JComponent component) {
		JPanel cell = new JPanel(new BorderLayout());
		cell.setBorder(BorderFactory.createEtchedBorder());
		cell.add(component, BorderLayout.CENTER);
		return cell;
	}

	@Override
	public void init(JPanel panel) {
		FormLayout layout = new FormLayout(this.columnSpecs);
		DefaultFormBuilder builder = new DefaultFormBuilder(layout, panel);
		builder.setDefaultDialogBorder();
	}

	/**
	 * Gets the column specifications for a row
	 * 
	 * @return Column specification
	 * @see FormLayout
	 */
	public String getColumnSpecs() {
		return this.columnSpecs;
	}

	/**
	 * Sets the column specifications for a row
	 * 
	 * @param columnSpecs
	 *            Column specification
	 * @see FormLayout
	 */
	public void setColumnSpecs(String columnSpecs) {
		this.columnSpecs = columnSpecs;
	}

}
