package net.sf.doolin.gui.lf;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import javax.swing.UIManager;
import javax.swing.UIManager.LookAndFeelInfo;

import net.sf.doolin.gui.action.path.item.ActionPath;
import net.sf.doolin.gui.action.path.item.GUIActionPath;
import net.sf.doolin.gui.action.path.list.ActionPathList;
import net.sf.doolin.util.Utils;

import org.apache.commons.lang.StringUtils;

/**
 * Generation of a group of actions for the management of look and feels
 * 
 * @author Damien Coraboeuf
 * 
 */
public class LookAndFeelActionPathList implements ActionPathList {

	private String pathPrefix = "";
	private List<String> lfNameList;
	private List<LookAndFeelInfo> lfList;

	@Override
	public List<ActionPath> getPaths() {
		List<ActionPath> actionPaths = new ArrayList<ActionPath>();
		// Paths
		List<String> paths = new ArrayList<String>(Arrays.asList(StringUtils
				.split(this.pathPrefix, ";")));
		// List of all L&F
		List<LookAndFeelInfo> lfList = getLFList();
		// For each Look and Feel
		for (LookAndFeelInfo lf : lfList) {
			// Look and feel action
			LFAction lfAction = new LFAction();
			lfAction.setLookAndFeelInfo(lf);
			// Action path
			GUIActionPath actionPath = new GUIActionPath(lfAction, paths);
			// OK
			actionPaths.add(actionPath);
		}
		// OK
		return actionPaths;
	}

	/**
	 * Sets a list of additional look and feels
	 * 
	 * @param lfList
	 *            List of look and feels
	 */
	public void setLfList(List<LookAndFeelInfo> lfList) {
		this.lfList = lfList;
	}

	/**
	 * Sets additional L&F class names
	 * 
	 * @param lfList
	 *            List of look and feels
	 */
	public void setLfNameList(List<String> lfList) {
		this.lfNameList = lfList;
	}

	/**
	 * Sets the path prefix to use when constructing the action paths (empty by
	 * default)
	 * 
	 * @param pathPrefix
	 *            Path prefix
	 */
	public void setPathPrefix(String pathPrefix) {
		this.pathPrefix = pathPrefix;
	}

	private List<LookAndFeelInfo> getLFList() {
		List<LookAndFeelInfo> lfInfoList = new ArrayList<LookAndFeelInfo>();
		// Default ones
		LookAndFeelInfo[] infos = UIManager.getInstalledLookAndFeels();
		lfInfoList.addAll(Arrays.asList(infos));
		// Additional look and feels by name
		if (this.lfNameList != null) {
			for (String lfName : this.lfNameList) {
				LookAndFeelInfo lfInfo = (LookAndFeelInfo) Utils
						.newInstance(lfName);
				lfInfoList.add(lfInfo);
			}
		}
		// Additional look and feels infos
		if (this.lfList != null) {
			lfInfoList.addAll(this.lfList);
		}
		// OK
		return lfInfoList;
	}
}
