package net.sf.doolin.gui.model;

import net.sf.doolin.util.Utils;
import net.sf.doolin.util.factory.DataFactory;

import org.springframework.beans.factory.annotation.Required;

/**
 * Calls a method on a property of the context in order to get the result. By
 * default, the property is set to "this" so the method is called directly on
 * the context.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of the model
 */
public class MethodDataFactory<V> implements DataFactory<V> {

	private String propertyPath = "";
	private String methodName;

	@Override
	public V create(Object context) {
		@SuppressWarnings("unchecked")
		V bean = (V) context;
		// Bean to call the method on
		Object subBean = Utils.getProperty(bean, this.propertyPath);
		// Calls the method
		Utils.callMethod(subBean, this.methodName);
		// OK
		return bean;
	}

	/**
	 * Sets the Path to the bean to call the method on
	 * 
	 * @param propertyPath
	 *            Path to the bean to call the method on
	 */
	public void setPropertyPath(String propertyPath) {
		this.propertyPath = propertyPath;
	}

	/**
	 * Sets the method to call on the context
	 * 
	 * @param methodName
	 *            Method name
	 */
	@Required
	public void setMethodName(String methodName) {
		this.methodName = methodName;
	}
}
