/*
 * Created on Jul 18, 2007
 */
package net.sf.doolin.gui.service;

/**
 * List of available sizes for icons.
 * 
 * @author Damien Coraboeuf
 */
public enum IconSize {
	/**
	 * Mini icon (12)
	 */
	MINI(12),
	/**
	 * Small icon (16)
	 */
	SMALL(16),
	/**
	 * Medium icon (24)
	 */
	MEDIUM(24),
	/**
	 * Large icon (32)
	 */
	LARGE(32),
	/**
	 * Big icon (64)
	 */
	BIG(64);
	/**
	 * Preferred size
	 */
	private int preferredSize;

	/**
	 * Constructor
	 */
	IconSize(int aPreferredSize) {
		this.preferredSize = aPreferredSize;
	}

	/**
	 * @return Bigger size or <code>null</code> if not available
	 */
	public IconSize getBiggerSize() {
		IconSize[] sizes = IconSize.values();
		int count = sizes.length;
		int ordinal = this.ordinal();
		if (ordinal < count - 1) {
			return sizes[ordinal + 1];
		} else {
			return null;
		}
	}

	/**
	 * @return Preferred size in pixels
	 */
	public int getPreferredSize() {
		return this.preferredSize;
	}

	/**
	 * @return Smaller size or <code>null</code> if not available
	 */
	public IconSize getSmallerSize() {
		int ordinal = this.ordinal();
		if (ordinal == 0) {
			return null;
		} else {
			return IconSize.values()[ordinal - 1];
		}
	}

}
