package net.sf.doolin.gui.spring;

import java.util.List;

import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.beans.factory.config.BeanDefinitionHolder;
import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.xml.AbstractSingleBeanDefinitionParser;
import org.springframework.beans.factory.xml.BeanDefinitionDecorator;
import org.springframework.beans.factory.xml.ParserContext;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

/**
 * Parser for a list that can be used both as a parser or a decorator.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class ListDecorator extends AbstractSingleBeanDefinitionParser implements
		BeanDefinitionDecorator {

	private final String listName;

	/**
	 * Constructor
	 * 
	 * @param listName
	 *            Name of the property of the containing bean that contains the
	 *            list
	 */
	public ListDecorator(String listName) {
		this.listName = listName;
	}

	@Override
	protected void doParse(Element element, ParserContext parserContext,
			BeanDefinitionBuilder builder) {
		// Parses the list
		List<?> list = parserContext.getDelegate().parseListElement(element,
				builder.getBeanDefinition());
		// Sets the list in the parent
		BeanDefinition containingBeanDefinition = parserContext
				.getContainingBeanDefinition();
		if (containingBeanDefinition != null) {
			containingBeanDefinition.getPropertyValues().addPropertyValue(
					listName, list);
		}
		// OK
		super.doParse(element, parserContext, builder);
	}

	@Override
	public BeanDefinitionHolder decorate(Node node,
			BeanDefinitionHolder holder, ParserContext parserContext) {
		Element element = (Element) node;
		// Parses the list
		List<?> list = parserContext.getDelegate().parseListElement(element,
				holder.getBeanDefinition());
		// Sets the list
		holder.getBeanDefinition().getPropertyValues().addPropertyValue(
				listName, list);
		// OK
		return holder;
	}

}
