package net.sf.doolin.gui.spring.table;

import net.sf.doolin.context.spring.SimpleDefinitionParser;
import net.sf.doolin.gui.field.table.renderer.LabelInfoTableCellRenderer;
import net.sf.doolin.gui.swing.DateLabelInfoProvider;

import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.xml.ParserContext;
import org.w3c.dom.Element;

/**
 * Decorator for a {@link LabelInfoTableCellRenderer} based on
 * {@link DateLabelInfoProvider}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class ColumnDateDecorator extends
		SimpleDefinitionParser<LabelInfoTableCellRenderer> {

	/**
	 * Instantiates a new column date decorator.
	 */
	public ColumnDateDecorator() {
		super(LabelInfoTableCellRenderer.class);
		setContainerProperty("renderer");
	}

	@Override
	public void doParse(Element element, ParserContext parserContext,
			BeanDefinitionBuilder builder) {
		// Attributes
		String style = element.getAttribute("style");
		String timeStyle = element.getAttribute("timeStyle");
		String format = element.getAttribute("format");
		// Creates the label info provider
		DateLabelInfoProvider infoProvider = new DateLabelInfoProvider();
		infoProvider.setStyle(style);
		infoProvider.setTimeStyle(timeStyle);
		infoProvider.setFormat(format);
		// Sets into the contained bean
		builder.addPropertyValue("labelProvider", infoProvider);
		// OK
		super.doParse(element, parserContext, builder);
	}

}
