package net.sf.doolin.gui.swing;

import java.util.ArrayList;
import java.util.List;

/**
 * Abstract implementation for a {@link IFilePath} that provides support for the
 * listeners.
 * 
 * @author Damien Coraboeuf
 * 
 */
public abstract class AbstractFilePath implements IFilePath {

	private final List<FilePathListener> listeners = new ArrayList<FilePathListener>(
			1);

	@Override
	public synchronized void addFilePathListener(
			FilePathListener filePathListener) {
		this.listeners.add(filePathListener);
	}

	/**
	 * Fires to all listeners that the path has changed.
	 * 
	 * @param text
	 *            Next text
	 * @see FilePathListener#filePathChanged(String)
	 */
	protected void fireNewPath(String text) {
		List<FilePathListener> copy = new ArrayList<FilePathListener>(
				this.listeners);
		for (FilePathListener filePathListener : copy) {
			filePathListener.filePathChanged(text);
		}
	}

	@Override
	public synchronized void removeFilePathListener(
			FilePathListener filePathListener) {
		this.listeners.remove(filePathListener);
	}

}
