package net.sf.doolin.gui.swing;

import javax.swing.Icon;

import net.sf.doolin.gui.expression.GUIExpression;
import net.sf.doolin.gui.service.IconService;
import net.sf.doolin.gui.service.IconSize;
import net.sf.doolin.gui.service.icon.DefaultIconService;

import org.springframework.beans.factory.annotation.Autowired;

/**
 * {@link LabelInfoProvider} based on a {@link GUIExpression}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class ExpressionLabelInfoProvider implements LabelInfoProvider {

	private String expression;
	private String iconExpression;
	private IconService iconService = new DefaultIconService();

	/**
	 * Default constructor
	 */
	public ExpressionLabelInfoProvider() {
	}

	/**
	 * Constructor with a default expression
	 * 
	 * @param expression
	 *            Expression to use
	 */
	public ExpressionLabelInfoProvider(String expression) {
		this.expression = expression;
	}

	/**
	 * Returns the expression
	 * 
	 * @return Expression
	 */
	public String getExpression() {
		return this.expression;
	}

	/**
	 * Returns the expression used to get icon id
	 * 
	 * @return Expression
	 */
	public String getIconExpression() {
		return this.iconExpression;
	}

	@Override
	public LabelInfo getLabelIcon(Object item) {
		// Text
		GUIExpression guiExpression = new GUIExpression(null, item,
				this.expression);
		String value = guiExpression.getValue();
		// Icon
		Icon icon = null;
		if (this.iconExpression != null) {
			String iconKey = new GUIExpression(null, item, this.iconExpression)
					.getValue();
			icon = this.iconService.getIcon(iconKey, IconSize.SMALL);
		}
		// OK
		return new LabelInfo(value, icon);
	}

	/**
	 * Sets the expression to use
	 * 
	 * @param expression
	 *            Expression
	 */
	public void setExpression(String expression) {
		this.expression = expression;
	}

	/**
	 * Sets the expression to use to get the icon id
	 * 
	 * @param iconExpression
	 *            Expression
	 */
	public void setIconExpression(String iconExpression) {
		this.iconExpression = iconExpression;
	}

	/**
	 * Sets the icon service used to access icons
	 * 
	 * @param iconService
	 *            Icon service
	 */
	@Autowired(required = false)
	public void setIconService(IconService iconService) {
		this.iconService = iconService;
	}

}
