package net.sf.doolin.gui.swing;

import java.util.Map;

import javax.swing.Icon;

import net.sf.doolin.gui.service.IconService;
import net.sf.doolin.gui.service.IconSize;
import net.sf.doolin.gui.service.icon.DefaultIconService;
import net.sf.doolin.gui.util.GUIStrings;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Required;

/**
 * {@link LabelInfoProvider} based on a map of keys, that give access to the
 * text and icons.
 * 
 * @author Damien Coraboeuf (x74639)
 * 
 */
public class KeyLabelInfoProvider implements LabelInfoProvider {

	private Map<Object, String> keyMap;

	private IconService iconService = new DefaultIconService();

	@Override
	public LabelInfo getLabelIcon(Object item) {
		String key = this.keyMap.get(item);
		if (key != null) {
			// Text
			String text = " ";
			if (GUIStrings.isDefined(key)) {
				text = GUIStrings.get(key);
			}
			// Icon
			Icon icon = null;
			String iconKey = key + ".icon";
			if (GUIStrings.isDefined(iconKey)) {
				String iconId = GUIStrings.get(iconKey);
				icon = this.iconService.getIcon(iconId, IconSize.SMALL);
			}
			// OK
			return new LabelInfo(text, icon);
		} else {
			return new LabelInfo(" ");
		}
	}

	/**
	 * Gets the key map.
	 * 
	 * @return the key map
	 */
	public Map<Object, String> getKeyMap() {
		return this.keyMap;
	}

	/**
	 * Sets the key map.
	 * 
	 * @param keyMap
	 *            the key map
	 */
	@Required
	public void setKeyMap(Map<Object, String> keyMap) {
		this.keyMap = keyMap;
	}

	/**
	 * Gets the icon service used to access icons
	 * 
	 * @return Icon service
	 */
	public IconService getIconService() {
		return this.iconService;
	}

	/**
	 * Sets the icon service used to access icons
	 * 
	 * @param iconService
	 *            Icon service
	 */
	@Autowired(required = false)
	public void setIconService(IconService iconService) {
		this.iconService = iconService;
	}

}
