package net.sf.doolin.gui.swing;

import java.awt.Component;

import javax.swing.DefaultListCellRenderer;
import javax.swing.JList;
import javax.swing.ListCellRenderer;

/**
 * {@link ListCellRenderer} based on a {@link LabelInfoProvider}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class LabelInfoListCellRenderer extends DefaultListCellRenderer {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	private LabelInfoProvider labelProvider = new DefaultLabelInfoProvider();

	/**
	 * Constructor.
	 * 
	 * @param labelProvider
	 *            {@link LabelInfoProvider} this renderer is based upon.
	 */
	public LabelInfoListCellRenderer(LabelInfoProvider labelProvider) {
		this.labelProvider = labelProvider;
	}

	/**
	 * Constructor without any label provider.
	 */
	public LabelInfoListCellRenderer() {
	}

	@Override
	public Component getListCellRendererComponent(JList list, Object value,
			int index, boolean isSelected, boolean cellHasFocus) {
		// Get label info
		LabelInfo labelIcon = this.labelProvider.getLabelIcon(value);
		// Text
		String text = labelIcon.getText();
		// OK
		super.getListCellRendererComponent(list, text, index, isSelected,
				cellHasFocus);
		// Icon
		setIcon(labelIcon.getIcon());
		// OK
		return this;
	}

	/**
	 * Gets the label info provider
	 * 
	 * @return {@link LabelInfoProvider}
	 */
	public LabelInfoProvider getLabelProvider() {
		return this.labelProvider;
	}

	/**
	 * Sets the label info provider
	 * 
	 * @param labelProvider
	 *            Label info provider
	 */
	public void setLabelProvider(LabelInfoProvider labelProvider) {
		this.labelProvider = labelProvider;
	}

}
