package net.sf.doolin.gui.system;

import java.util.Locale;
import java.util.Map;
import java.util.Properties;

import net.sf.doolin.bus.bean.Bean;

import org.apache.commons.lang.ObjectUtils;

import ca.odell.glazedlists.BasicEventList;
import ca.odell.glazedlists.EventList;

/**
 * Model that contains information about the system.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class SystemInformationModel extends Bean {

	private static final long serialVersionUID = 1L;

	private final EventList<SystemInformation> systemInformationList;

	/**
	 * Constructor.
	 */
	public SystemInformationModel() {
		// Creates the list
		this.systemInformationList = new BasicEventList<SystemInformation>();

		// System properties
		Properties properties = System.getProperties();
		for (Map.Entry<Object, Object> entry : properties.entrySet()) {
			Object key = entry.getKey();
			Object value = entry.getValue();
			SystemInformation si = new SystemInformation(
					SystemInformationType.SYSTEM, ObjectUtils.toString(key),
					ObjectUtils.toString(value));
			this.systemInformationList.add(si);
		}

		// Environment variables
		Map<String, String> env = System.getenv();
		for (Map.Entry<String, String> entry : env.entrySet()) {
			String key = entry.getKey();
			String value = entry.getValue();
			SystemInformation si = new SystemInformation(
					SystemInformationType.ENVIRONMENT, key, value);
			this.systemInformationList.add(si);
		}

		// Runtime properties
		Runtime runtime = Runtime.getRuntime();
		this.systemInformationList.add(new SystemInformation(
				SystemInformationType.RUNTIME, "freeMemory", String.format(
						Locale.UK, "%,d", runtime.freeMemory())));
		this.systemInformationList.add(new SystemInformation(
				SystemInformationType.RUNTIME, "totalMemory", String.format(
						Locale.UK, "%,d", runtime.totalMemory())));
		this.systemInformationList
				.add(new SystemInformation(SystemInformationType.RUNTIME,
						"availableProcessors", String.format(Locale.UK, "%,d",
								runtime.availableProcessors())));
		this.systemInformationList.add(new SystemInformation(
				SystemInformationType.RUNTIME, "maxMemory", String.format(
						Locale.UK, "%,d", runtime.maxMemory())));
	}

	/**
	 * @return the systemInformationList
	 */
	public EventList<SystemInformation> getSystemInformationList() {
		return this.systemInformationList;
	}

}
