package net.sf.doolin.gui.validation;

import net.sf.doolin.gui.util.GUIStrings;

/**
 * Validation message
 * 
 * @author Damien Coraboeuf
 * 
 */
public class GUIValidationMessage {

	private final Object key;
	private final String msgKey;
	private final Object[] params;

	/**
	 * Constructor
	 * 
	 * @param key
	 *            Validation key
	 * @param msgKey
	 *            Validation message key
	 * @param params
	 *            Validation message parameters
	 */
	public GUIValidationMessage(Object key, String msgKey, Object... params) {
		this.key = key;
		this.msgKey = msgKey;
		this.params = params;
	}

	/**
	 * Gets the displayable text for this message and for the current locale.
	 * 
	 * @return Message
	 */
	public String formattedText() {
		return GUIStrings.get(this.msgKey, this.params);
	}

	/**
	 * Key that identifies the field this validation message applies to.
	 * 
	 * @return Field key
	 */
	public Object key() {
		return this.key;
	}

}
