package net.sf.doolin.gui.view.decorator;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import javax.swing.JComponent;

import net.sf.doolin.gui.view.GUIView;

/**
 * Chain of view decorators.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class ChainedGUIViewDecorator extends AbstractGUIViewDecorator {

	private List<GUIViewDecorator> decorators = new ArrayList<GUIViewDecorator>(
			0);

	/**
	 * Default constructor with an empty chain of decorators
	 */
	public ChainedGUIViewDecorator() {
	}

	/**
	 * Constructor from a list of decorators
	 * 
	 * @param decorators
	 *            List of decorators to apply
	 */
	public ChainedGUIViewDecorator(GUIViewDecorator... decorators) {
		this.decorators = Arrays.asList(decorators);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public <V> JComponent decorate(GUIView<V> view, JComponent component,
			DecorationStyle decorationStyle) {
		for (GUIViewDecorator decorator : decorators) {
			component = decorator.decorate(view, component, decorationStyle);
		}
		return component;
	}

	/**
	 * Gets the decorators.
	 * 
	 * @return the decorators
	 */
	public List<GUIViewDecorator> getDecorators() {
		return decorators;
	}

	/**
	 * Sets the decorators.
	 * 
	 * @param decorators
	 *            the new decorators
	 */
	public void setDecorators(List<GUIViewDecorator> decorators) {
		this.decorators = decorators;
	}

}
