package net.sf.doolin.gui.view.support;

import java.awt.BorderLayout;

import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JToolBar;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.action.path.ActionBarContext;
import net.sf.doolin.gui.action.path.list.ActionPathList;
import net.sf.doolin.gui.action.swing.ActionFactory;
import net.sf.doolin.gui.swing.DockLayout;
import net.sf.doolin.gui.swing.ScrollablePanel;
import net.sf.doolin.gui.view.descriptor.GUIViewDescriptor;
import net.sf.doolin.gui.window.GUIWindow;

/**
 * View based on a panel.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of object for the view
 */
public class DefaultGUIView<V> extends AbstractGUIView<V> {

	private final JPanel containerPanel;
	private final JPanel viewPanel;

	/**
	 * Constructor.
	 * 
	 * @param parentWindow
	 *            Parent window
	 * @param viewDescriptor
	 *            View descriptor
	 * @param model
	 *            View model
	 * @param scrollable
	 *            <code>true</code> if the view content must be scrollable
	 */
	public DefaultGUIView(GUIWindow<?> parentWindow,
			GUIViewDescriptor<V> viewDescriptor, V model, boolean scrollable) {
		super(parentWindow, viewDescriptor, model);
		// Container
		this.containerPanel = new JPanel(new DockLayout());
		// View panel
		this.viewPanel = new JPanel();
		// Scrollable
		if (scrollable) {
			// Scrollable panel
			ScrollablePanel scrollablePanel = new ScrollablePanel(
					this.viewPanel);
			// Creates the scroll pane
			JScrollPane scrollPane = new JScrollPane(scrollablePanel);
			// OK
			this.containerPanel.add(scrollPane, BorderLayout.CENTER);
		} else {
			this.containerPanel.add(this.viewPanel, BorderLayout.CENTER);
		}
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public JComponent getViewComponent() {
		return this.containerPanel;
	}

	/**
	 * Gets the view panel.
	 * 
	 * @return the view panel
	 */
	public JPanel getViewPanel() {
		return this.viewPanel;
	}

	@Override
	public void installToolBar(ActionPathList toolBar,
			ActionContext actionContext) {
		// Action factory
		ActionFactory actionFactory = getViewDescriptor().getActionFactory();
		// Creates the tool bar
		JToolBar jtoolBar = actionFactory.createToolBar(new ActionBarContext(
				toolBar, actionContext));
		jtoolBar.setFloatable(false);
		// Adds the tool bar
		this.containerPanel.add(jtoolBar, BorderLayout.NORTH);
	}
}
