package net.sf.doolin.gui.window.descriptor;

import java.awt.BorderLayout;

import javax.swing.Icon;
import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;

import net.sf.doolin.gui.service.IconSize;
import net.sf.doolin.gui.view.GUIView;
import net.sf.doolin.gui.view.support.GUIViewUtils;
import net.sf.doolin.gui.window.GUIWindow;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.Validate;

/**
 * Window descriptor that arranges views in their own tabs.
 * 
 * @param <B>
 *            Type of data for the window
 * @author Damien Coraboeuf
 */
public class TabbedGUIWindowDescriptor<B> extends
		AbstractCompositeGUIWindowDescriptor<B, Object> {

	@Override
	protected <V> void arrangeViewInWindow(GUIWindow<B> window,
			GUIView<V> view, JComponent viewDecoratedComponent,
			Object constraint) {
		// Gets the tabbed pane
		JTabbedPane tabbedPane = (JTabbedPane) window
				.getProperty(TabbedGUIWindowDescriptor.class);
		Validate.notNull(tabbedPane,
				"No tabbed pane is associated with the window");
		// Title of the view
		String title = GUIViewUtils.getTitle(view);
		// Icon of the view
		Icon icon = null;
		String iconId = view.getViewDescriptor().getIconId();
		if (StringUtils.isNotBlank(iconId)) {
			icon = getIconService().getIcon(iconId, IconSize.SMALL);
		}
		// TODO Updates the tab title as the title changes
		// TODO Updates the tab icon as the icon changes
		// Adds the view component as a tab
		tabbedPane.addTab(title, icon, viewDecoratedComponent);
	}

	@Override
	protected void arrangeWindow(GUIWindow<B> window) {
		// Gets the window content
		JPanel windowPanel = window.getWindowPanel();
		// Sets its layout
		windowPanel.setLayout(new BorderLayout());
		// Creates the tabbed pane
		JTabbedPane tabbedPane = new JTabbedPane();
		// Adds it to the window
		windowPanel.add(tabbedPane, BorderLayout.CENTER);
		// Registers it in the window
		window.setProperty(TabbedGUIWindowDescriptor.class, tabbedPane);
	}

}
