package net.sf.doolin.gui.window.opener;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.view.GUIView;
import net.sf.doolin.gui.view.descriptor.GUIViewDescriptor;
import net.sf.doolin.gui.window.GUIWindow;
import net.sf.doolin.gui.window.descriptor.GUIWindowDescriptor;

import org.springframework.beans.factory.annotation.Required;

/**
 * Opens a new view inside the window.
 * 
 * @author Damien Coraboeuf
 * @param <V>
 *            Type of data for the view
 */
public class InnerViewOpener<V> extends AbstractViewOpener<V> {

	private GUIViewDescriptor<V> viewDescriptor;

	/**
	 * Gets the view descriptor.
	 * 
	 * @return the view descriptor
	 */
	public GUIViewDescriptor<V> getViewDescriptor() {
		return this.viewDescriptor;
	}

	/**
	 * Open view.
	 * 
	 * @param <W>
	 *            Type of data for the window
	 * 
	 * @param window
	 *            the window
	 * @param viewDescriptor
	 *            the view descriptor
	 * @param contextModel
	 *            the context model
	 * @return Opened view
	 */
	protected <W> GUIView<V> openView(GUIWindow<W> window,
			GUIViewDescriptor<V> viewDescriptor, V contextModel) {
		// Window descriptor
		GUIWindowDescriptor<W> windowDescriptor = window.getWindowDescriptor();
		// Opens the view
		GUIView<V> view = windowDescriptor.openView(window, viewDescriptor,
				contextModel);
		// OK
		return view;
	}

	@Override
	protected ActionContext openViewInternal(ActionContext actionContext,
			V model) {
		// Gets the window
		GUIWindow<?> parentWindow = actionContext.getWindow();
		// Opens the view
		GUIView<V> view = openView(parentWindow, this.viewDescriptor, model);
		// OK
		return view.getActionContext();
	}

	/**
	 * Sets the view descriptor.
	 * 
	 * @param viewDescriptor
	 *            the new view descriptor
	 */
	@Required
	public void setViewDescriptor(GUIViewDescriptor<V> viewDescriptor) {
		this.viewDescriptor = viewDescriptor;
	}

}
