package net.sf.doolin.gui.window.support;

import java.awt.Container;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JRootPane;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.swing.SwingUtils;

/**
 * Window implementation based on a {@link JFrame}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class FrameIWindow extends AbstractIWindow<JFrame> {

	/**
	 * Constructor
	 * 
	 * @param actionContext
	 *            Action context
	 */
	public FrameIWindow(ActionContext actionContext) {
		super(actionContext);
	}

	/**
	 * Creates a {@link JFrame}.
	 * 
	 * @see SwingUtils#createWindow(Class, java.awt.Component)
	 */
	@Override
	protected JFrame buildWindow() {
		JFrame dialog = SwingUtils.createWindow(JFrame.class,
				getActionContext().getComponent());
		dialog.setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
		return dialog;
	}

	@Override
	public Container getContentPane() {
		return getWindow().getContentPane();
	}

	@Override
	public JRootPane getRootPane() {
		return getWindow().getRootPane();
	}

	@Override
	public boolean isModal() {
		return false;
	}

	@Override
	public void pack() {
		getWindow().pack();
	}

	@Override
	public void setDefaultButton(JButton button) {
		getWindow().getRootPane().setDefaultButton(button);
	}

	@Override
	public void setTitle(String value) {
		getWindow().setTitle(value);
	}

}
