package net.sf.doolin.gui.wizard.rule;

import java.util.List;

import org.springframework.beans.factory.annotation.Required;

/**
 * Simple wizard navigation rule that just follows a fixed sequence of views.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <B>
 */
public class SequenceWizardRules<B> extends AbstractWizardRules<B> {

	private List<String> sequence;

	/**
	 * The wizard can be finished if the current view is the last one.
	 */
	@Override
	public boolean canFinish(String currentViewId, B model) {
		return this.sequence.indexOf(currentViewId) == (this.sequence.size() - 1);
	}

	/**
	 * The wizard can be navigated to the next view if there is at least one
	 * view before the end of the sequence.
	 */
	@Override
	public String getNext(String currentViewId, B model) {
		int index = this.sequence.indexOf(currentViewId);
		if (index < this.sequence.size() - 1) {
			return this.sequence.get(index + 1);
		} else {
			return null;
		}
	}

	/**
	 * Sets the sequence of views
	 * 
	 * @param sequence
	 *            List of view names
	 */
	@Required
	public void setSequence(List<String> sequence) {
		this.sequence = sequence;
	}

}
