package net.sf.doolin.gui.wizard.rule.condition;

/**
 * Individual rule that is evaluated for a view. If this rule is evaluated to
 * <code>true</code>, then its {@linkplain #getResult() result} will be used as
 * the next view to navigate to. A special result if {@link #FINISH} (
 * <code>null</code>) which means that the view can be finished.
 * 
 * @author Damien Coraboeuf
 * 
 */
public interface WizardRule {

	/**
	 * Special result (@{value}) which means that the view can be finished.
	 */
	String FINISH = null;

	/**
	 * Evaluates the rule against the wizard bean. If the evaluation returns
	 * <code>true</code>, the wizard can be navigated to the rule result (or
	 * Finish if this result is <code>null</code>).
	 * 
	 * @param model
	 *            Wizard bean
	 * @return Result of the evaluation
	 */
	boolean evaluate(Object model);

	/**
	 * Gets the result of this rule, either the view the wizard can be navigated
	 * to or <code>null</code> if the wizard can be finished.
	 * 
	 * @return Rule result
	 */
	String getResult();

}
