package net.sf.doolin.gui.wizard.support;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.display.AndDisplayStateHandler;
import net.sf.doolin.gui.display.DisplayStateHandler;
import net.sf.doolin.gui.display.ValidationDisplayStateHandler;
import net.sf.doolin.gui.wizard.state.NextDisplayStateHandler;
import net.sf.doolin.gui.wizard.state.WizardState;

/**
 * "Previous" action for the wizard.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class WizardNextAction extends AbstractWizardAction {

	/**
	 * Constructor.
	 */
	public WizardNextAction() {
		this("Wizard.action.next");
	}

	/**
	 * Constructor with custom text
	 * 
	 * @param text
	 *            Text for the button
	 */
	public WizardNextAction(String text) {
		this(text, new NextDisplayStateHandler());
	}

	/**
	 * Constructor with custom text and display state handler. The handler will
	 * be associated with a {@link ValidationDisplayStateHandler}.
	 * 
	 * @param text
	 *            Text for the button
	 * @param handler
	 *            Display state handler
	 */
	public WizardNextAction(String text, DisplayStateHandler handler) {
		super(WizardAction.NEXT, text);
		setDisplayStateHandler(new AndDisplayStateHandler(
				new ValidationDisplayStateHandler(), handler));
	}

	/**
	 * Gets the {@link WizardState} from the context and calls its
	 * {@link WizardState#doNext(ActionContext)} method.
	 */
	@Override
	protected void doExecute(ActionContext context) throws Exception {
		WizardState<?> state = (WizardState<?>) context.getContext();
		state.doNext(context);
	}

	@Override
	protected String getShortcut() {
		return "ctrl KP_RIGHT";
	}

}
