package net.sf.doolin.gui.wizard.support;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import javax.swing.JButton;
import javax.swing.SwingUtilities;

import net.sf.doolin.gui.view.GUIView;
import net.sf.doolin.gui.window.dialog.AbstractDialogWindow;
import net.sf.doolin.gui.window.dialog.DialogActionsFactory;
import net.sf.doolin.gui.window.support.IWindowFactory;
import net.sf.doolin.gui.wizard.descriptor.WizardDescriptor;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class WizardWindow<B> extends AbstractDialogWindow<B> {

	private static final Logger log = LoggerFactory.getLogger(WizardWindow.class);

	/**
	 * Constructor
	 * 
	 * @param wizardActionsFactory
	 *            Factory for the wizard actions (previous, next, finish, cancel...)
	 */
	public WizardWindow(DialogActionsFactory wizardActionsFactory) {
		super(wizardActionsFactory);
	}

	@Override
	public void addView(GUIView<?> view) {
		super.addView(view);
		setDefaultButtons();
	}

	@Override
	protected IWindowFactory getIwindowFactory() {
		WizardDescriptor<B> descriptor = (WizardDescriptor<B>) getWindowDescriptor();
		return descriptor.getIwindowFactory();
	}

	@Override
	protected boolean isModal() {
		WizardDescriptor<B> descriptor = (WizardDescriptor<B>) getWindowDescriptor();
		return descriptor.isModal();
	}

	/**
	 * Creates the button bar
	 */
	@Override
	public void onPostCreate() {
		super.onPostCreate();

		// Default button is 1) the Finish button, 2) the Next button, according
		// to the first enabled one.
		JButton finishButton = getButton(WizardAction.FINISH);
		JButton nextButton = getButton(WizardAction.NEXT);
		// Activation of the buttons
		PropertyChangeListener listener = new PropertyChangeListener() {

			@Override
			public void propertyChange(PropertyChangeEvent evt) {
				setDefaultButtons();
			}
		};
		// Listens to their enablement
		if (finishButton != null) {
			finishButton.addPropertyChangeListener("enabled", listener);
		}
		if (nextButton != null) {
			nextButton.addPropertyChangeListener("enabled", listener);
		}
		// Default state
		setDefaultButtons();
	}

	/**
	 * Sets the default buttons
	 */
	public void setDefaultButtons() {
		JButton finishButton = getButton(WizardAction.FINISH);
		if (finishButton != null) {
			// All available buttons
			JButton nextButton = getButton(WizardAction.NEXT);
			// Computation
			final JButton defaultButton;
			if (nextButton.isEnabled()) {
				defaultButton = nextButton;
			} else if (finishButton.isEnabled()) {
				defaultButton = finishButton;
			} else {
				defaultButton = null;
			}
			// OK
			SwingUtilities.invokeLater(new Runnable() {

				@Override
				public void run() {
					if (log.isDebugEnabled()) {
						if (defaultButton != null) {
							log.debug("Setting default button to " + defaultButton.getText());
						} else {
							log.debug("Removing any default button");
						}
					}
					setDefaultButton(defaultButton);
					// this.commandPanel.repaint();
				}
			});
		}
	}

}
