package net.sf.doolin.gui.docking;

import java.awt.Dimension;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * Description for the docked views in a window. It can stored and restored.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class DockDescription implements Serializable {

	private static final long serialVersionUID = 1L;

	private final String className;
	private final boolean leaf;
	private final String position;
	private final Dimension size;

	private final List<String> viewIds = new ArrayList<String>();
	private final List<DockDescription> descriptions = new ArrayList<DockDescription>();

	/**
	 * Constructor.
	 * 
	 * @param className
	 *            Class of the dock
	 * @param leaf
	 *            <code>true</code> if this dock is a leaf
	 * @param position
	 *            Position of the dock relatively to its parent
	 * @param size
	 *            Size of this dock
	 */
	public DockDescription(String className, boolean leaf, String position,
			Dimension size) {
		this.className = className;
		this.leaf = leaf;
		this.position = position;
		this.size = size;
	}

	/**
	 * Adds a child to this dock
	 * 
	 * @param description
	 *            Child dock description
	 */
	public void add(DockDescription description) {
		this.descriptions.add(description);
	}

	/**
	 * Gets the class of the dock
	 * 
	 * @return Class
	 */
	public String getClassName() {
		return this.className;
	}

	/**
	 * Gets the list of children dock descriptions.
	 * 
	 * @return List of children dock descriptions.
	 */
	public List<DockDescription> getDescriptions() {
		return this.descriptions;
	}

	/**
	 * Gets the position of this dock
	 * 
	 * @return Position
	 */
	public String getPosition() {
		return this.position;
	}

	/**
	 * Gets the size of this dock
	 * 
	 * @return Size
	 */
	public Dimension getSize() {
		return this.size;
	}

	/**
	 * Gets the list of view IDs that the window contains.
	 * 
	 * @return List of view IDs
	 */
	public List<String> getViewIds() {
		return this.viewIds;
	}

	/**
	 * Checks if this dock is a leaf
	 * 
	 * @return <code>true</code> if this dock is a leaf
	 */
	public boolean isLeaf() {
		return this.leaf;
	}

	@Override
	public String toString() {
		return String.format("%s @ %s", this.className, this.position);
	}

}
