package net.sf.doolin.gui.docking;

import java.awt.BorderLayout;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.JComponent;
import javax.swing.JPanel;

import net.sf.doolin.gui.view.GUIView;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Component that is associated to a {@linkplain GUIView view} for being stored
 * in a {@linkplain com.javadocking.dockable.Dockable dockable}.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of data for the view
 */
public class DockingComponent<V> extends JPanel {

	private static final long serialVersionUID = 1L;

	private static final Logger log = LoggerFactory.getLogger(DockingComponent.class);

	private final GUIView<V> view;

	/**
	 * Constructor
	 * 
	 * @param view
	 *            Hosted view
	 * @param viewDecoratedComponent
	 *            View's component
	 */
	public DockingComponent(GUIView<V> view, JComponent viewDecoratedComponent) {
		this.view = view;
		// Layout
		setLayout(new BorderLayout());
		add(viewDecoratedComponent, BorderLayout.CENTER);
		// Focus management
		setFocusable(true);
		FocusRequester focusRequester = new FocusRequester();
		addMouseListener(focusRequester);
		addFocusListener(focusRequester);
	}

	/**
	 * Focus management
	 * 
	 * @author Damien Coraboeuf
	 * 
	 */
	public class FocusRequester extends MouseAdapter implements FocusListener {

		@Override
		public void mouseClicked(MouseEvent e) {
			DockingComponent.this.requestFocusInWindow();
		}

		@Override
		public void focusGained(FocusEvent e) {
			activateView();
		}

		@Override
		public void focusLost(FocusEvent e) {
		}

	}

	/**
	 * Activates the view
	 */
	public void activateView() {
		if (log.isDebugEnabled()) {
			log.debug(String.format("Activating view %s", this.view.getID()));
		}
		this.view.show();
	}

	/**
	 * Gets the associated view
	 * 
	 * @return View
	 */
	public GUIView<V> getView() {
		return this.view;
	}

}
